{# This is an interesting example. In this case, the endpoint_requirements
is account/keys. Of course, account/keys cannot be a valid dictionary key
name, si all '/' will get replaced by '_'. The dictionary will be named
"account_keys". #}
{% set endpoint_requirements = ['account/keys'] %}
# Automatically generated by https://www.github.com/buanzo/digitalocean-metawrite
# Author: Arturo 'Buanzo' Busleiman

{% for key in account_keys.ssh_keys %}
# Key "{{ key.name }}" ID={{ key.id }} Fingerprint={{key.fingerprint}}
{{ key.public_key }}
{% endfor %}
